<h1 align="center">transformer-as-service</h1>

<p align="center">Using transformer pretrained model as a sentence encoding service, i.e. mapping a variable-length sentence to a fixed-length vector.</p>

Thanks for the idea from [bert-as-serivce](https://github.com/hanxiao/bert-as-service)